@@ -115,17 +115,6 @@ writeWKB <- function(obj, endian = "little") {
 
     SpatialPointsToWKBPoint(obj, endian)
 
-  } else if(inherits(obj, "list") && length(obj) > 0 &&
-          all(vapply(
-            X = obj,
-            FUN = inherits,
-            FUN.VALUE = logical(1),
-            c("SpatialPoints", "SpatialPointsDataFrame"))
-            )
-          ) {
-
-    ListOfSpatialPointsToWKBMultiPoint(obj, endian)
-
   } else if(inherits(obj, c("SpatialLines", "SpatialLinesDataFrame"), which = FALSE)) {
 
     SpatialLinesToWKBMultiLineString(obj, endian)
@@ -134,6 +123,18 @@ writeWKB <- function(obj, endian = "little") {
 
     SpatialPolygonsToWKBPolygon(obj, endian)
 
+  } else if(inherits(obj, "list") && length(obj) > 0 &&
+            all(vapply(
+              X = obj,
+              FUN = inherits,
+              FUN.VALUE = logical(1),
+              c("SpatialPoints", "SpatialPointsDataFrame"),
+              which = FALSE)
+            )
+  ) {
+
+    ListOfSpatialPointsToWKBMultiPoint(obj, endian)
+
   } else {
 
     stop("obj must be an object of class SpatialPoints, SpatialPointsDataFrame, ",
